#pragma once

#include "GeometryNode.h"
#include "SceneInfo.h"

#include "Line.h"

#include <vector>

class LineNode : public GeometryNode
{
public:
    LineNode(const Point& location, const std::vector<Point>& points)
        : GeometryNode(location),
            mPoints(points)
    {

    }

    Type getType()
    {
        return Type::Line;
    }

    void createOrUpdateGeometry(SceneInfo* sceneInfo)
    {
        if (sceneInfo->mSupportsGeometryPrimitives)
        {
            auto line = std::make_unique<Line>(Point{ 0, 0 }, 1, 1);
            mBackgroundItem = std::make_unique<SceneModel>(std::move(line));
        }
        mBackgroundItem->setName(mName + "_Model");
    }

    void updateTransform()
    {
        mBackgroundItem->updateTransform({ mLocation });
    }

private:
    std::vector<Point> mPoints;
};